@@ -181,5 +181,5 @@ def main():
     cli_obj = ResumeParserCli()
     pprint(cli_obj.extract_resume_data())
 
-if __name__ == "__main__":
-    main()
+# if __name__ == "__main__":
+#     main()
